@@ -10,4 +10,6 @@ utils::globalVariables(c("id",
                          "permissionType",
                          "spaceUsed",
                          "spaceUsedInt",
-                         "description"))
+                         "description",
+                         "fieldType",
+                         "."))
